#!/usr/bin/perl 
#===============================================================================
#
#         FILE:  dvr2-atfilter.pl
#
#        USAGE:  ./dvr2-atfilter.pl  
#
#  DESCRIPTION:  Mail filter for at job output
#
#       AUTHOR:  Copyright (c) 2012 Hiro Sugawara
#      VERSION:  1.0
#      CREATED:  02/15/2012 08:48:38
#     REVISION:  ---
#===============================================================================

use strict;
use warnings;

#
# Expect recording job output to comply with a strict pattern.
# Pass only abnormal mail.
#

#
# Strict filter patterns in order (except space-only lines)
#
my @ATFILTER = (
	'CHANNEL : \d+',
	'DURATION: \d+',
	'OUTPUT  : .*\.ts',
	'TUNER : \d',
	'TYPE : .+',
	'MODE : \d',
	'pid = \d+',
	'C\/N = \d+\.\d+dB',
	'Recording\.\.\.',
	'Available sid = (\d+ )+',
	'Chosen sid    = \d+',
	'Recorded \d+sec',
	'job \d+ at [FMSTW]\w\w [ADFJMNOS]\w\w [\d ]\d \d\d:\d\d:\d\d \d{4}',
	'job \d+ at [FMSTW]\w\w [ADFJMNOS]\w\w [\d ]\d \d\d:\d\d:\d\d \d{4}',
);

my $text = '';
my $bad = 0;

sub procHeader {
	while (<STDIN>) {
		$text .= $_;
		chomp;
		last if ($_ eq '');
		if (/^Subject: /) {
			$bad = 1 unless (/^Subject: Output from your job\s+\d+$/);
		}
	}
}

sub procBody {
	while (<STDIN>) {
		$text .= $_;
		chomp;
		next if (/^\s*$/);
		unless ($bad) {
			my $filter = shift @ATFILTER;
			unless (defined($filter)) {
				$bad = 1;
				$text .= "^\n";
				next;
			}
			unless (/^$filter$/) {
				$bad = 1;
				$text .= "^\n";
			}
		}
	}
}

procHeader();
procBody();

print $text if ($bad);
